@@ -323,9 +323,9 @@ class ClickHouseBaseNode(ClickHouseTools):
             raise ValueError(f'sql must be str or list or tuple,but get {type(sql)}')
         return result
 
-    def get_describe_table(self, db, table):
+    def get_describe_table(self, db, table, filter=['MATERIALIZED', 'ALIAS']):
         describe_sql = 'describe table {}.{}'.format(db, table)
-        describe_table = self.__execute__(describe_sql, convert_to='dataframe', transfer_sql_format=False,
+        describe_table = self.__execute__(describe_sql, convert_to='dataframe', transfer_sql_format=True,
                                           loop=None, to_df=True, raise_error=True)
         # non_nullable_columns = list(describe_table[~describe_table['type'].str.startswith('Nullable')]['name'])
         # integer_columns = list(describe_table[describe_table['type'].str.contains('Int', regex=False)]['name'])
@@ -334,7 +334,7 @@ class ClickHouseBaseNode(ClickHouseTools):
         # df_columns = list(df.columns)
         # each_row = df.to_dict(orient='records')
         # del df
-        return describe_table  # , integer_columns, non_nullable_columns
+        return describe_table[~describe_table['default_type'].isin(filter)]  # , integer_columns, non_nullable_columns
 
         # return df_columns, each_row
 
@@ -347,6 +347,9 @@ class ClickHouseBaseNode(ClickHouseTools):
         :return:
         """
         describe_table = self.get_describe_table(db, table)
+        dt_col = describe_table[describe_table['type'].isin('DateTime', 'Nullable(DateTime)')]['name'].values.ravel()
+        for i in dt_col:
+            df[i] = pd.to_datetime(df[i]).dt.strftime('%Y-%m-%d %H:%M:%S')
         row_count = df.shape[0]
         rows_data = (i for i in self._check_df_and_dump(df, describe_table))
         if row_count <= chunksize:
